@@ -83,7 +83,10 @@ def run(code, _stack=(), _lst=(), u=None, _inputs=()):
         elif char == 'A':
             stack.push(stack.first(list) + [stack.first(list, False)])
         elif char == 'C':
-            a, b = stack.first(list, n=2)
+            b, a = stack.first(list, n=2)
+            stack.push(a + b)
+        elif char == '_':
+            b, a = stack.first(str, n=2)
             stack.push(a + b)
         elif char == 'R':
             a = stack.first((list, str))
@@ -305,6 +308,15 @@ def run(code, _stack=(), _lst=(), u=None, _inputs=()):
             stack.push(list(inputs).copy())
         elif char == ')':
             stack.push(inputs[0])
+        elif char == '`':
+            index += 1
+            string = code[index]
+            a = stack.first((list, str))
+            l = []
+            for i in a:
+                stack, lst = run(string, [i] + stack, lst, u, inputs)
+                l.append(stack[0])
+            stack.push(l)
         else:
             if isinstance(stack[0], str):
                 stack[0] += code[index]
